# Hello World

This is an example project demonstrating how to publish a python module to PyPI.
All Help was took from the youtube video <[How To Publish A Package On PyPI](https://youtu.be/QgZ7qv4Cd0Y)>

## Installation

Run the following to install:

```python
pip install hello-niksingh710
```

## Usage

```python
from hello_niksingh710 import say_hello

# calling say_hello() returns a String --> "Hello, World! :)"

print(say_hello())

# calling say_hello("Everybody") returns a String --> "Hello, Everybody :)"

print(say_hello())


```
